package com.bonus.canteen.core.supermarket.service;

import java.util.List;
import com.bonus.canteen.core.supermarket.domain.SupermarketInfo;

/**
 * 超市Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface ISupermarketInfoService {
    /**
     * 查询超市
     * 
     * @param supermarketId 超市主键
     * @return 超市
     */
    public SupermarketInfo selectSupermarketInfoBySupermarketId(Long supermarketId);

    /**
     * 查询超市列表
     * 
     * @param supermarketInfo 超市
     * @return 超市集合
     */
    public List<SupermarketInfo> selectSupermarketInfoList(SupermarketInfo supermarketInfo);

    /**
     * 新增超市
     * 
     * @param supermarketInfo 超市
     * @return 结果
     */
    public int insertSupermarketInfo(SupermarketInfo supermarketInfo);

    /**
     * 修改超市
     * 
     * @param supermarketInfo 超市
     * @return 结果
     */
    public int updateSupermarketInfo(SupermarketInfo supermarketInfo);

    /**
     * 批量删除超市
     * 
     * @param supermarketIds 需要删除的超市主键集合
     * @return 结果
     */
    public int deleteSupermarketInfoBySupermarketIds(Long[] supermarketIds);

    /**
     * 删除超市信息
     * 
     * @param supermarketId 超市主键
     * @return 结果
     */
    public int deleteSupermarketInfoBySupermarketId(Long supermarketId);
}
