package com.bonus.canteen.core.supermarket.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supermarket.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supermarket.domain.SupermarketInfo;
import com.bonus.canteen.core.supermarket.service.ISupermarketInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 超市Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "超市接口")
@RestController
@RequestMapping("/supermarket_info")
public class SupermarketInfoController extends BaseController {
    @Autowired
    private ISupermarketInfoService supermarketInfoService;

    /**
     * 查询超市列表
     */
    @ApiOperation(value = "查询超市列表")
    //@RequiresPermissions("supermarket:info:list")
    @GetMapping("/list")
    public TableDataInfo list(SupermarketInfo supermarketInfo) {
        if (supermarketInfo.isPagenation()) {
            startPage();
        }
        List<SupermarketInfo> list = supermarketInfoService.selectSupermarketInfoList(supermarketInfo);
        return getDataTable(list);
    }

    /**
     * 导出超市列表
     */
    @ApiOperation(value = "导出超市列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:info:export")
    @SysLog(title = "超市", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出超市")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupermarketInfo supermarketInfo) {
        List<SupermarketInfo> list = supermarketInfoService.selectSupermarketInfoList(supermarketInfo);
        ExcelUtil<SupermarketInfo> util = new ExcelUtil<SupermarketInfo>(SupermarketInfo.class);
        util.exportExcel(response, list, "超市数据");
    }

    /**
     * 获取超市详细信息
     */
    @ApiOperation(value = "获取超市详细信息")
    //@RequiresPermissions("supermarket:info:query")
    @GetMapping(value = "/{supermarketId}")
    public AjaxResult getInfo(@PathVariable("supermarketId") Long supermarketId) {
        return success(supermarketInfoService.selectSupermarketInfoBySupermarketId(supermarketId));
    }

    /**
     * 新增超市
     */
    @ApiOperation(value = "新增超市")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:info:add")
    @SysLog(title = "超市", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增超市")
    @PostMapping
    public AjaxResult add(@RequestBody SupermarketInfo supermarketInfo) {
        try {
            return toAjax(supermarketInfoService.insertSupermarketInfo(supermarketInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改超市
     */
    @ApiOperation(value = "修改超市")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:info:edit")
    @SysLog(title = "超市", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改超市")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupermarketInfo supermarketInfo) {
        try {
            return toAjax(supermarketInfoService.updateSupermarketInfo(supermarketInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除超市
     */
    @ApiOperation(value = "删除超市")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:info:remove")
    @SysLog(title = "超市", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除超市")
	@PostMapping("/del/{supermarketIds}")
    public AjaxResult remove(@PathVariable Long[] supermarketIds) {
        return toAjax(supermarketInfoService.deleteSupermarketInfoBySupermarketIds(supermarketIds));
    }
}
